import org.maemo.hermes.engine.facebook.service

from org.maemo.hermes.engine.names import canonical


class Service(org.maemo.hermes.engine.facebook.service.Service):
    """LinkedIn backend for Hermes.
                
       Copyright (c) Fredrik Wendt <fredrik@wendt.se> 2010.
       Released under the Artistic Licence."""
       
       
    # -----------------------------------------------------------------------
    def __init__(self, service_id, linkedInApi):
        org.maemo.hermes.engine.facebook.service.Service.__init__(self, service_id, None)
        self.linkedInApi = linkedInApi

    
    # -----------------------------------------------------------------------
    def process_friends(self):
        friends = self.linkedInApi.get_friends()
        for friend in friends:
            self._register_friend(friend)


    # -----------------------------------------------------------------------
    def is_profile_url(self, url):
        """Return True if this is a URL for this service."""

        return url and "linkedin.com" in url

